@@ -33,7 +33,7 @@ deal with git subrepositories.
 
 =cut
 
-our $VERSION = '0.15';
+our $VERSION = '0.16';
 
 =head1 PACKAGE VARS
 
@@ -420,7 +420,7 @@ This is the exported name of C<each>
 sub _run_in_repo {
     my ($cmd, $repo, $config, $ia_config) = @_;
 
-    return App::Multigit::Future->done( $config->{dir} => "Readonly" )
+    return App::Multigit::Future->done
         if $BEHAVIOUR{skip_readonly} and $config->{readonly};
 
     if (ref $cmd eq 'ARRAY') {
